@@ -1,5 +1,6 @@
 """CG errors."""
 
+
 class RayvisionError(Exception):
     """Raise RayvisionError if something wrong."""
 
@@ -21,5 +22,22 @@ class RayvisionError(Exception):
 class UnsupportedDatabaseError(Exception):
     """The local database supports only Redis and Sqlite"""
 
+
 class UnsupportedEngineType(Exception):
-    """Engine Only Support aspera and raysync"""
\ No newline at end of file
+    """Engine Only Support aspera and raysync"""
+
+
+class DownloadFailed(Exception):
+    """Download failed"""
+
+    def __init__(self, error, *args, **kwargs):
+        """Initialize error message, inherited Exception.
+
+        Args:
+            error (str): Error message.
+            args (set): Other parameters.
+            kwargs (dict): Other keyword parameters.
+
+        """
+        super(DownloadFailed, self).__init__(self, error, *args, **kwargs)
+        self.error = error
